@@ -1,6 +1,6 @@
 package common::sense;
 
-our $VERSION = 3.73;
+our $VERSION = 3.74;
 
 # overload should be included
 
@@ -10,7 +10,7 @@ sub import {
    ${^WARNING_BITS} ^= ${^WARNING_BITS} ^ "\x0c\x3f\x33\x00\x0f\xf0\x0f\xc0\xf0\xfc\x33\x00\x00\x00\xc0";
    # use strict, use utf8; use feature;
    $^H |= 0x1c820fc0;
-   @^H{qw(feature___SUB__ feature_switch feature_fc feature_state feature_say feature_unicode feature_evalbytes)} = (1) x 7;
+   @^H{qw(feature_unicode feature_fc feature_evalbytes feature_state feature_switch feature___SUB__ feature_say)} = (1) x 7;
 }
 
 1
